bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift A ## 14. Aventiure
___________________________________________________ #### <Wie <die> chvniginnen an ander schvlten>
| ### or einer vesperzit huop sich groz vngemach ### daz von manigen reken vf dem hove esach ### si pflagen riterschefte durch kurzwile wan ### do liefen dar durch schowen manich wip vnde man
###### 758 | ### Zesamne do gesazen die kvniginne rich ### si gedahten zweir reken die warn lobelich ### do sprach div schoene Kriemhilt ich han einen nman ### daz elliv disiv riche zuo sinen handen solden stan
###### 759 | ### Do sprach div vroewe Prunhilt wie kvnde daz gesin [31b] ### ob ander nieman lebete wan din vn– sin ### so mohten im div riche wol wesen vndertan ### die wile daz lebet Gvnther so kvndez nimmer ergan
###### 760 | ### Do sprach aber Kriemhilt sihestv wie er stat ### wie rehte herliche er vor den reken gat ### sam der liehte mane vor den sternen tvot ### des mvos ich von schvlden tragen vrolichen mvot
###### 761 | ### Do sprach div vrowe Prvnhilt swie watlich si din man ### biderbe vnd swi schoene so soltv vor im lan ### Gvnther den reken den edeln bruoder din ### der mvoz vor allen kvnigen daz wizze werliche sin
###### 762 | ### Do sprach aber Kriemhilt so tiwer ist min man ### daz ich in an schvlde niht gelobet han ### an vil manigen dingen ist sin ere groez ### gelovbest dv daz Prvnhilt er ist wol Gvnthers genoz
###### 763 | ### Ia soltu mirz Kriemhilt ze arge niht verstan ### wan ich an schvlde niht die rede han getan ### ich horte si iehen beide do ich si erste sach ### vn– da des kvniges wille an mime libe gesach
###### 764 | ### vnd da er mine minne so riterlich gewan ### do iach Sifrit er were des kvniges man ### des han ich in fur eigen sit ich ins horte iehen ### do sprach div schoene Kriemhilt so wer mir vbel geschehen
###### 765 | ### Wie heten so geworben die edelen bruoder min ### daz ich eigenmannes wine solde sin ### des wil ich dich Prvnhilt vil frivntlichen biten ### daz dv last die rede durch mich mit guetlichen siten
###### 766 | ### Iich mag ir niht gelazen sprach des kvniges wip ### zwiv sold ich verchiesen so maniges riters lip ### der vns mit dem degne dienstlich ist vndertan ### Kriemhilt div vil schoene daz sere zvrnen began
###### 767 | ### Dv mvst in verchiesen daz er dir immer bi ### wone deheiner dienste er ist tiwer danne si ### Gvnther min bruoder der vil edel man ### dv sold mich des erlazen daz ich von dir venomen han
###### 768 | ### Vnde nimet mich imer wunder sit er din eigen ist ### vnd dv uber vns <beidiv> so gewaltich bist ### daz er dir so lange den cins versezzen hat ### diner vbermvote sold ich von rehte haben rat
###### 769 | ### Dv civhest dich ze hohe sprach do des kvnige wip ### nv wil ich sehen gerne ob man dinen lip ### habe ce solhen eren so man den minnen tuot ### die frowen wurden beide vil sere zornich genuoch
###### 770 | ### Do sprach div vrowe Kriemhilt daz muoz et nv geschehen ### sit dv mines mannes fur eigen hast geiehen ### so muozen hivte kiesen der beider kvnige man ### ob ich vor kvniges wibe ce kirche turre gegan
###### 771 | ### Dv muost daz hivte schowen daz ich bin <adelfri> ### vnd daz min man ist tiwere danne der din si ### da mite wil ich selbe bescholden sin [32a] ### du solt noch heint kiesen wie div eigene din
###### 772 | ### ze houe ge uor reken in Burgonden lant ### ich wil wesen tiwer danne ieman habe bechant ### deheine kvniginne div krone her ie getruoch ### do huop sich vnder den vrowen grozes nides genvch
###### 773 | ### Do sprach aber Prvnhilt wil dv niht eigen sin ### so muost du dich scheiden mit den vrowen din ### von minem ingesinde da wir ce munster gan ### des antwrte Kriemhilt triwen daz sol sin getan
###### 774 | ### Nu cheidet iuch min meide sprach Sifrides wip ### ez muoz ane schande beliben hie min lip ### ir svlt wol lazen schovwen habet ir iht riche wat ### si mac sin gerne lovgen des si hie veriehen hat
###### 775 | ### Man mohte in lihte raten si svochten richiv kleit ### da wart vil wol gecieret manich vrowe vnd meit ### do gie mit ir gesinde des edelen kvniges wip ### da wart ovch wol gecieret der schoenen Kriemhilde lip
###### 776 | ### mit drin vnd vierzech meiden brahte si an den Rin ### die truogen liehte pfelle geworht in Arabin ### svs komen zuo dem mvnster die meide wolgetan ### ir warten vor dem huose alle Sifrides man
###### 777 | ### Die lute man des wunder wa von daz gesach ### daz man die kvnniginne also gescheiden sach ### daz si bi an ander niht giengen alsam ê ### da von wart manigem degne sid vil sorchlichen we
###### 778 | ### Hie stuont vor dem mvnster Gvnthers wip ### do hete chvrzwile vil maniges riters lip ### mit den schoenen frowen der si da namen ware ### do kom div schoene Kiemhilt mit maniger herlichen schare
###### 779 | ### Swaz kleider ie getrvgen edelr riter kint ### wider ir gesinde daz was gar ein wint ### si was so rich des guotes daz drizech kvniges wip ### ez mohten niht erzivgen daz eine erzivgte ir lip
###### 780 | ### Oob ieman wunschen solde der kvnde niht gesagen ### <daz> man so richer cleider gesehe ie me getragen ### so da ze stvnde truogen ir meide wolgetan ### wan Prvnhilde ze leide ez hete Kriemhilt verlan
###### 781 | ### Zesamne si do komen vor dem mvnster wit ### ez tet div hvsvrowe durch einen grozen nit ### si hiez vil <vbeliche> Kriemhilde stan ### ia sol vor kvniges wibe nimmer eigen wip gegan
###### 782 | ### Do sprach div schoene Kriemhilt zornec was ir mvt ### kvndestv noch swigen daz wær dir lihte guot ### dv hast geschendet dinen schoenen lip ### wie moehte mannes kebse immer werden <kvniges> wip
###### 783 | ### Wem hastv hie verkebset sprach des kvniges wip ### daz han ich dich sprach Kriemhilt dinen schonen lip ### minnete erst Sifrit min vil lieber man ### ia was ez niht din bruoder der dinen meidem gewan
###### 784 | ### War komen dine sinne ez was ein arger list [32b] ### daz dv in lieze minnen sit er din eigen ist ### ich hoere dich sprach Kriemhilt an schvlde clagen ### triwen sprach do Prvnhilt daz wil ich <Gunthe >
###### 785 | ### Waz mac mir daz gewerren din vbermuot dich hat betrogen ### dv hast mich ce dienste mit rede dich an gezogen ### daz wizze an rehten triwen ez ist mir immer leit ### getriwer heinliche sol ich dir wesen vmbereit
###### 786 | ### Prvnhilt do weinde Kriemhilt niht lenger lie ### vor des kvniges wibe inz mvnster si do gie ### mit ir ingesinde da huop sich grozer haz ### da wurden liehtiv ovgen starke truobe vnde naz
###### 787 | ### Swie vil man gote diende oder ieman da sanch ### des duhte Prvnhilde div wile gar ze lanch ### wand ir was vil truebe der lip vnd ovch der muot ### des muoste sit enkelten manich helt kuene vn– guot
###### 788 | ### Prunhilt vnd ir vrowen gie fur daz mvnster stan ### si dahte mich muez Kriemhilt mere hoeren lan ### des mich so lûte cihet daz wortraze wip ### hat er sichs geruemet ez get im werlich an den lip
###### 789 | ### Nv kom div edel Kriemhilt mit manigem kuenen man ### do sprach div edel Prunhilt ir svlt noch stille stan ### er iahet mich ce chebsen daz svlt ir lazen sehen ### mir ist von iwren spruchen daz wizzet leide geschehen
###### 790 | ### Do sprach vro Criemhilt ir moehtet mich lan gan ### ich erzivgez mit dem golde daz ich enhende han ### daz brahte mir Sifrit do er bi iv lach ### nie gelebte Brunhilt deheinen leidern tac
###### 791 | ### Si sprach daz golt vil edel daz wart mir verstolen ### vnd ist mich harte lange vbel verholn ### ich kvm ez an ein ende wer mirz hat genomen ### die vrowen waren beide in groz vngemuote komen
###### 792 | ### Do sprach aber Kriemhilt ich wils niht wesen diep ### dv mohtest gedaget han were dir ere liep ### ich erzivgez mit dem gvrtel den ich vmbe han ### daz ich niht livge ia wart Sifrit din man
###### 793 | ### Von Ninneue den siden si den borten truoc ### mit edelen gesteine ia was er guot genuoch ### do den gesach vro Brvnhilt weinen si began ### daz muoste freischen Gvnther dar zuo alle sine man
###### 794 | ### Do sprach div kvniginne heizet here gan ### den fursten von Rine ich wil in hoeren lan ### wie mich hat gehoenet siner swester lip ### si seit hie offenliche ich si Sifrides wip
###### 795 | ### Der kvnich kom mit reken weinen er do sach ### <sine> trivttinne guotlich er do sprach ### saget mir liebiv vrowe wer hat iv iht getan ### si sprach zuo dem kvnige ich muoz vnfrolichen stan
###### 796 | ### Von allen minen eren mich div swester din ### gerne wolde scheiden dir sol gechlaget sin ### si gihet mich habe gechebeset Sifrit ir man [33a] ### do sprach der kvnich Gvnther so hetes vbele getan
###### 797 | ### Si treit hie minen gvrtel den ich han verlorn ### vnde min golt daz rote daz ich ie wart geborn ### daz riwet mich sere dvn beredest kvnich mich ### der vil grozen schanden ich minne niemer dich
###### 798 | ### Do sprach kvnich Gvnther er sol her fur gan ### hat er sichs geruomet daz sol er hoeren lan ### oder sin muoz laugen der helt vz Niderlant ### do wart der kuene Sifrit harte balde dar besant
###### 799 | ### Do der herre Sifrit die vngemuoten sach ### er weste niht der mere balde er do sprach ### waz weinet dise vrovwen daz het ich gerne erkant ### oder von welhen schvlden ich da here si besant
###### 800 | ### Do sprach kvnich Gvnther mir ist harte leit ### mir hat min vrowe Prunhilt ein mære hie geseit ### du hast dich geruomet dv werst ir erster man ### so seit din wip Kriemhilt hastv degen daz getan
###### 801 | ### Nein ich sprach do Sifrit vn– hat si daz geseit ### end ich erwinde daz muoz ir werden leit ### vnd wil dirz <gerihten> vor allen dinen man ### mit minen hohen eiden daz ich irz nih gesaget han
###### 802 | ### Do sprach der kvnich von Rine daz soltu lazen sehen ### den zit den dv bivtest mach der hie gesehen ### aller valschen dingen wil ich dich ledech lan ### man sach zuo dem ringe do die von Burgonden stan
###### 803 | ### Sifrit der vil kuene zem eide bot die hant ### do sprach der kvnich rike mir ist so wol bechant ### iwer groz vnschvlde ich wil iv ledech lan ### des iuch min swester cihet daz ir des niht habet getan
###### 804 | ### Do sprach aber Sifrit vnd genivzzet des ir lip ### daz si hat ertuebet din vil schoene wip ### daz ist mir sicherlichen ane maze leit ### do sahen zuo an ander die kuenen rittere gemeit
###### 805 | ### Man sol so vrowen ziehen sprach Sifrit der degen ### daz si vppech spruche lazen vnder wegen ### verbivt ez dinem wibe der minen tuon ich sam ### solher vbermvote ich mich werlichen scham
###### 806 | ### Mit rede wart gescheiden manich schoene wip ### do trurte also sere Brunhilde ir lip ### daz ez erbarmen muose die Gvnthers man ### do kom von Trony Hagne zuo siner vrowen gegan
###### 807 | ### <Er> vragte waz ir wære weinende er si vant ### do seite si im div mere er lobete ir sa zehant ### daz ez erarnen muose Kriemhilde man ### oder er wolde nimmer darvmbe vrolich gestan
###### 808 | ### Zuo der rede komen Ortwin vnd Gernot ### da die helde rieten den Sifrides tot [33b] ### dar zuo kom ovch Giselher der schoenen voten kint ### do er ir rede gehorte er sprach getriwlichen sint
###### 809 | ### Ir vil guoten reken warvmbe tuot ir daz ### ia gediende Sifrit nie alsolhen haz ### daz er darvmbe solde verliesen sinen lip ### ia ist des harte lihte darvmbe zvrnent div wip
###### 810 | ### Svln wir hohe ziehen sprach aber Hagne ### des habent luzel ere so guote degene ### daz er sich hat geruemet der lieben vrowen min ### darvmbe wil ich sterben ez enge im an daz leben sin
###### 811 | ### Do sprach der kvnich selbe er hat vns niht getan ### niwan guot vnd ere man sol in leben lan ### waz tuoch ob ich dem reken were nv gehaz ### er was vns ie getriwen vnd tet vil willeclichen daz
###### 812 | ### Do sprach von Mezen der degen Ortwin ### ia kan in niht gehelfen div groze sterke sin ### erlovbet mirz min herre ich tvon im alse leit ### do heten im die helde ane schvlde widerseit
###### 813 | ### Sin gevolgte nieman niwan daz Hagne ### riet in allen ziten Gvnther dem degne ### ob Sifrit niht enlebte so wurde im vndertan ### vil der kvnige lande der helt des truren began
###### 814 | ### Do liezen siz do beliben spiln man do sach ### hey waz man starker schefte vor dem mvnster brach ### vor Sifrides wibe al zuo dem sale dan ### do waren in vnmvote genvoge Gvnthers man
###### 815 | ### Der kvnich sprach lat beliben den mortlichen zorn ### er ist vns ze selden vn– ze eren geborn ### ovch ist so starc grimme der wundern kuene man ### wurde er sin innen so torst in nieman bestan
###### 816 | ### Nein er sprach do Hagne lat iv ez wol behagen ### ich trovwe ez heinliche also an getragen ### daz Brvnhilde weinen sol im werden leit ### im sol von Hagnen immer wesen widerseit
###### 817 | ### Do sprach der kvnich Gvnther wie mohte daz ergan ### des antwurte Hagne ich wil ivchz hoeren lan ### heizen boten riten zvo vns in daz lant ### widersagen offenliche die hie niemen sin bechant
###### 818 | ### So iehet ir vor den gesten daz ir vnd iwer man ### wellent herverten also daz ist getan ### so lobet er iv dar dienen des flivset er den lip ### so ervare ich vns div mere an des reken kuenen wip
###### 819 | ### Der kvnich vbel volgte Hagnen sinen man ### die starken vntriwe begvnden tragen an ### ê ieman daz erfvnde die riter vz erkorn ### von zweier vrovwen bagen wart vil manich helt verlorn

<<< Übersicht <<< vorige Seite nächste Seite >>>